TextArea

Struct TextArea 

pub struct TextArea {
    pub x: u32,
    pub y: u32,
    pub max_width: u32,
    pub scale: PxScale,
    pub font: FontArc,
    pub align: Align,
    pub color: Color,
}
A configurable text drawing area with wrapping and alignment.

Fields

x: u32

Starting X coordinate of the text box.

y: u32

Starting Y coordinate of the text box.

max_width: u32

Maximum width allowed before wrapping.

scale: PxScale

Font scale used for rendering text.

font: FontArc

Font used when drawing text.

align: Align

Horizontal alignment of each line.

color: Color

Color to draw the text in.

Implementations

Source

impl TextArea

pub fn to_lines(&self, text: &Text) -> Vec<Text>

Splits text into wrapped lines based on maximum width.

Source

impl TextArea

pub fn size(&self, text: impl ToString) -> Bounds

Returns the pixel size of the given text at this scale.

Source

impl TextArea

pub fn draw( &self, image: &mut DynamicImage, text: &str, ) -> Result<(), Box<dyn Error>>

Draws the given text inside the configured area.

Parses and styles the given text as markdown, and wraps and aligns the text as designated.

Source

impl TextArea

pub fn new( (x, y): (u32, u32), max_width: u32, color: Color, font: FontArc, scale: impl Into<PxScale>, align: Align, ) -> Self

Creates a new TextArea at the given position and width using the specified font and scale.